@@ -23,8 +23,8 @@
 #include <QTableWidget>
 #include <QTableWidgetItem>
 #include <QHeaderView>
-#include <kdebug.h>
-#include <klocale.h>
+#include "jabber_protocol_debug.h"
+#include <KLocalizedString>
 #include <kio/global.h>
 #include <kio/job.h>
 #include <kio/jobclasses.h>
@@ -52,7 +52,7 @@ JabberChooseServer::JabberChooseServer ( JabberRegisterAccount *parent )
 	mMainWidget->lblStatus->setText ( i18n ( "Retrieving server list...") );
 
 	// retrieve server list
-	mTransferJob = KIO::get ( KUrl("https://xmpp.net/services.php") );
+	mTransferJob = KIO::get ( QUrl(QStringLiteral("https://xmpp.net/services.php")) );
 
 	connect ( mTransferJob, SIGNAL (result(KJob*)), this, SLOT (slotTransferResult(KJob*)) );
 	connect ( mTransferJob, SIGNAL (data(KIO::Job*,QByteArray)), this, SLOT (slotTransferData(KIO::Job*,QByteArray)) );
@@ -107,7 +107,7 @@ void JabberChooseServer::slotTransferData ( KIO::Job */*job*/, const QByteArray
 
 	memcpy ( &xmlServerList.data()[oldSize], data.data (), data.size () );
 
-	kDebug ( JABBER_DEBUG_GLOBAL ) << "Server list now " << xmlServerList.size ();
+	qCDebug(JABBER_PROTOCOL_LOG) << "Server list now " << xmlServerList.size ();
 
 }
 
@@ -122,10 +122,10 @@ void JabberChooseServer::slotTransferResult ( KJob *kJob )
 	}
 	else
 	{
-		kDebug ( JABBER_DEBUG_GLOBAL ) << "Received server list ok!";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Received server list ok!";
 
 		// clear status message
-		mMainWidget->lblStatus->setText ( "" );
+		mMainWidget->lblStatus->setText ( QLatin1String("") );
 
 		// parse XML list
 		QDomDocument doc;
@@ -145,9 +145,9 @@ void JabberChooseServer::slotTransferResult ( KJob *kJob )
 			mMainWidget->listServers->insertRow ( listIndex );
 			QDomNamedNodeMap attributes = node.attributes ();
 
-			newItem = new QTableWidgetItem ( attributes.namedItem ( "jid" ).nodeValue () );
+			newItem = new QTableWidgetItem ( attributes.namedItem ( QStringLiteral("jid") ).nodeValue () );
 			mMainWidget->listServers->setItem ( listIndex, 0, newItem );
-			newItem = new QTableWidgetItem ( attributes.namedItem ( "name" ).nodeValue () );
+			newItem = new QTableWidgetItem ( attributes.namedItem ( QStringLiteral("name") ).nodeValue () );
 			mMainWidget->listServers->setItem ( listIndex, 1, newItem );
 		}
 
@@ -156,5 +156,3 @@ void JabberChooseServer::slotTransferResult ( KJob *kJob )
 
 }
 
-
-#include "jabberchooseserver.moc"
